@@ -4,11 +4,11 @@ ICON = "🪄"
 
 DESCRIPTION = f"{ICON} AI Algo."
 
-VERSION = "4.228.1"
+VERSION = "4.297.1"
 
 REPO_NAME = "bluer-algo"
 
-MARQUEE = "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true"
+MARQUEE = "https://github.com/kamangir/assets/raw/main/swallow-model-2025-07-11-15-04-03-2glcch/evaluation.png?raw=true"
 
 ALIAS = "@algo"
 
